@@ -27,6 +27,7 @@ class Client:
         "Content-Type": "application/json",
         "Accept-Encoding": "gzip, deflate, br",
         "Accept": "*/*",
+        "x-application": "AHWEBSHOP",
         "Connection": "keep-alive",
     }
     TEMP_DIR = os.path.join(tempfile.gettempdir(), "Supermarket-Connector", "Debug", "AH")
@@ -45,14 +46,19 @@ class Client:
         self,
         method: str,
         end_point: str,
-        headers: Dict[str, Any] = {},
-        params: Dict[str, Any] = {},
+        headers: Optional[Dict[str, Any]] = None,
+        params: Optional[Dict[str, Any]] = None,
         request_data: Optional[Dict[str, Any]] = None,
         timeout: int = 10,
         authorized: bool = True,
         json_: bool = True,
         debug_key: Optional[str] = None,
     ) -> Union[str, List[Any], Dict[Any, Any]]:
+        if headers is None:
+            headers = {}
+
+        if params is None:
+            params = {}
 
         headers.update(self.DEFAULT_HEADERS)
 
@@ -152,7 +158,7 @@ class Client:
     class Categories:
         def __init__(self, client: Client) -> None:
             self.__client = client
-            self.data: Dict[int, Client.Category] = {}
+            self.data: Dict[Union[int, str], Client.Category] = {}
 
         def list(self):
             response = self.__client.request("GET", "mobile-services/v1/product-shelves/categories")
@@ -196,10 +202,10 @@ class Client:
     class Products:
         def __init__(self, client: Client) -> None:
             self.__client = client
-            self.data: Dict[int, Dict[int, Client.Product]] = {}
+            self.data: Dict[Union[int, str], Dict[int, Client.Product]] = {}
 
         @typing.overload
-        def list(self) -> Dict[int, Dict[int, Client.Product]]:
+        def list(self) -> Dict[Union[int, str], Dict[int, Client.Product]]:
             ...
 
         @typing.overload
@@ -548,7 +554,7 @@ class Client:
             if id is None:
                 raise ValueError("Expected data to have ID")
 
-            super().__init__(id, slug_name, name, nix18, images, [])
+            super().__init__(id, slug_name, name, nix18, True, images, [])
 
         def list_subs(self, recursive: bool = True):
             response = self.__client.request("GET", f"mobile-services/v1/product-shelves/categories/{self.id}/sub-categories", debug_key="list_subcategories")
